@@ -2,7 +2,7 @@ import click
 
 from globus_cli.login_manager import LoginManager
 from globus_cli.parsing import ENDPOINT_PLUS_REQPATH, command
-from globus_cli.services.transfer import autoactivate, get_client
+from globus_cli.services.transfer import autoactivate
 from globus_cli.termio import FORMAT_TEXT_RAW, formatted_print
 
 
@@ -20,15 +20,15 @@ $ mkdir ep_id:~/testfolder
 )
 @click.argument("endpoint_plus_path", type=ENDPOINT_PLUS_REQPATH)
 @LoginManager.requires_login(LoginManager.TRANSFER_RS)
-def mkdir_command(endpoint_plus_path):
+def mkdir_command(*, login_manager: LoginManager, endpoint_plus_path):
     """Make a directory on an endpoint at the given path.
 
     {AUTOMATIC_ACTIVATION}
     """
     endpoint_id, path = endpoint_plus_path
 
-    client = get_client()
-    autoactivate(client, endpoint_id, if_expires_in=60)
+    transfer_client = login_manager.get_transfer_client()
+    autoactivate(transfer_client, endpoint_id, if_expires_in=60)
 
-    res = client.operation_mkdir(endpoint_id, path=path)
+    res = transfer_client.operation_mkdir(endpoint_id, path=path)
     formatted_print(res, text_format=FORMAT_TEXT_RAW, response_key="message")
