@@ -1,7 +1,7 @@
 import uuid
 
+from globus_cli.login_manager import LoginManager
 from globus_cli.parsing import command
-from globus_cli.services.search import get_search_client
 from globus_cli.termio import FORMAT_TEXT_RECORD, formatted_print
 
 from .._common import task_id_arg
@@ -24,9 +24,10 @@ TASK_FIELDS = [
 
 @command("show")
 @task_id_arg
-def show_command(task_id: uuid.UUID):
+@LoginManager.requires_login(LoginManager.SEARCH_RS)
+def show_command(*, login_manager: LoginManager, task_id: uuid.UUID):
     """Display a Task"""
-    search_client = get_search_client()
+    search_client = login_manager.get_search_client()
     formatted_print(
         search_client.get_task(task_id),
         fields=TASK_FIELDS,
