@@ -1,3 +1,4 @@
+from .client_login import get_client_login, is_client_login
 from .errors import MissingLoginError
 from .local_server import is_remote_session
 from .manager import LoginManager
@@ -16,4 +17,6 @@ __all__ = [
     "internal_auth_client",
     "internal_native_client",
     "token_storage_adapter",
+    "is_client_login",
+    "get_client_login",
 ]
