@@ -18,6 +18,7 @@ from .param_types import (
     IdentityType,
     JSONStringOrFile,
     LocationType,
+    ParsedIdentity,
     StringOrNull,
     TaskPath,
     UrlOrNull,
@@ -38,6 +39,7 @@ __all__ = [
     "JSONStringOrFile",
     "LocationType",
     "MutexInfo",
+    "ParsedIdentity",
     "StringOrNull",
     "TaskPath",
     "UrlOrNull",
